==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowTypeDescriptionMetadata } from "./WebRowTypeDescriptionMetadata";
import { WebGridRowTemplateContextDescription } from "./WebGridRowTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowTemplateContextDescriptionMetadata, _super);
    function WebGridRowTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowTemplateContextDescriptionMetadata.a == null) {
            WebGridRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowTemplateContextDescriptionMetadata.c(WebGridRowTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridRowTemplateContextDescriptionMetadata.a);
        WebRowTypeDescriptionMetadata.d(a);
    };
    WebGridRowTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebRowType");
    };
    WebGridRowTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowTemplateContextDescriptionMetadata.b(a);
        a.ad("WebGridRowTemplateContext", function () { return new WebGridRowTemplateContextDescription(); });
        a.ac("WebGridRowTemplateContext", WebGridRowTemplateContextDescriptionMetadata.a);
    };
    WebGridRowTemplateContextDescriptionMetadata.$t = markType(WebGridRowTemplateContextDescriptionMetadata, 'WebGridRowTemplateContextDescriptionMetadata');
    WebGridRowTemplateContextDescriptionMetadata.a = null;
    return WebGridRowTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebGridRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowTypeDescriptionMetadata } from "./WebRowTypeDescriptionMetadata";
import { WebGridRowTemplateContextDescription } from "./WebGridRowTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowTemplateContextDescriptionMetadata, _super);
    function WebGridRowTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowTemplateContextDescriptionMetadata.a == null) {
            WebGridRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowTemplateContextDescriptionMetadata.c(WebGridRowTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridRowTemplateContextDescriptionMetadata.a);
        WebRowTypeDescriptionMetadata.d(a);
    };
    WebGridRowTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebRowType");
    };
    WebGridRowTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowTemplateContextDescriptionMetadata.b(a);
        a.ae("WebGridRowTemplateContext", function () { return new WebGridRowTemplateContextDescription(); });
        a.ad("WebGridRowTemplateContext", WebGridRowTemplateContextDescriptionMetadata.a);
    };
    WebGridRowTemplateContextDescriptionMetadata.$t = markType(WebGridRowTemplateContextDescriptionMetadata, 'WebGridRowTemplateContextDescriptionMetadata');
    WebGridRowTemplateContextDescriptionMetadata.a = null;
    return WebGridRowTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowTemplateContextDescriptionMetadata };
